==> afb-app-manager_12.3.1.orig.tar.gz: afb-app-manager-12.3.1/src/wgtpkg/wgt-strings.c <==
/*
 Copyright (C) 2015-2024 IoT.bzh Company

 Author: José Bollo <jose.bollo@iot.bzh>

 $RP_BEGIN_LICENSE$
 Commercial License Usage
  Licensees holding valid commercial IoT.bzh licenses may use this file in
  accordance with the commercial license agreement provided with the
  Software or, alternatively, in accordance with the terms contained in
  a written agreement between you and The IoT.bzh Company. For licensing terms
  and conditions see https://www.iot.bzh/terms-conditions. For further
  information use the contact form at https://www.iot.bzh/contact.

 GNU General Public License Usage
  Alternatively, this file may be used under the terms of the GNU General
  Public license version 3. This license is as published by the Free Software
  Foundation and appearing in the file LICENSE.GPLv3 included in the packaging
  of this file. Please review the following information to ensure the GNU
  General Public License requirements will be met
  https://www.gnu.org/licenses/gpl-3.0.html.
 $RP_END_LICENSE$
*/

/* defined by/for config.xml */
const char string_author[] = "author";
const char string_content[] = "content";
const char string_defaultlocale[] = "defaultlocale";
const char string_description[] = "description";
const char string_email[] = "email";
const char string_encoding[] = "encoding";
const char string_feature[] = "feature";
const char string_height[] = "height";
const char string_href[] = "href";
const char string_icon[] = "icon";
const char string_id[] = "id";
const char string_id_lower[] = "id-lower";
const char string_id_underscore[] = "id-underscore";
const char string_license[] = "license";
const char string_name[] = "name";
const char string_param[] = "param";
const char string_preference[] = "preference";
const char string_readonly[] = "readonly";
const char string_required[] = "required";
const char string_short[] = "short";
const char string_src[] = "src";
const char string_type[] = "type";
const char string_value[] = "value";
const char string_version[] = "version";
const char string_viewmodes[] = "viewmodes";
const char string_widget[] = "widget";
const char string_width[] = "width";
const char string_config_dot_xml[] = "config.xml";

/* other strings */
const char string_AGL_prefix[] = FWK_PREFIX;
const char string_AGL_permission_prefix[] = FWK_PREFIX "permission:";
const char string_AGL_widget_prefix[] = FWK_PREFIX "widget:";
const char string_defined_permission[] = "defined-permission";
const char string_dict[] = "dict";
const char string_file_properties[] = "file-properties";
const char string_idaver[] = "idaver";
const char string_index[] = "index";
const char string_level[] = "level";
const char string_list[] = "list";
const char string_main[] = "main";
const char string_optional[] = "optional";
const char string_provided_api[] = "provided-api";
const char string_provided_binding[] = "provided-binding";
const char string_provided_unit[] = "provided-unit";
const char string_required_api[] = "required-api";
const char string_required_binding[] = "required-binding";
const char string_required_permission[] = "required-permission";
const char string_targets[] = "targets";
const char string_sharp_target[] = "#target";


const char feature_required_api[] = FWK_PREFIX "widget:required-api";
const char feature_required_permission[] = FWK_PREFIX "widget:required-permission";

==> afb-app-manager_12.3.3.orig.tar.gz: afb-app-manager-12.3.3/src/wgtpkg/wgt-strings.c <==
/*
 Copyright (C) 2015-2025 IoT.bzh Company

 Author: José Bollo <jose.bollo@iot.bzh>

 $RP_BEGIN_LICENSE$
 Commercial License Usage
  Licensees holding valid commercial IoT.bzh licenses may use this file in
  accordance with the commercial license agreement provided with the
  Software or, alternatively, in accordance with the terms contained in
  a written agreement between you and The IoT.bzh Company. For licensing terms
  and conditions see https://www.iot.bzh/terms-conditions. For further
  information use the contact form at https://www.iot.bzh/contact.

 GNU General Public License Usage
  Alternatively, this file may be used under the terms of the GNU General
  Public license version 3. This license is as published by the Free Software
  Foundation and appearing in the file LICENSE.GPLv3 included in the packaging
  of this file. Please review the following information to ensure the GNU
  General Public License requirements will be met
  https://www.gnu.org/licenses/gpl-3.0.html.
 $RP_END_LICENSE$
*/

/* defined by/for config.xml */
const char string_author[] = "author";
const char string_content[] = "content";
const char string_defaultlocale[] = "defaultlocale";
const char string_description[] = "description";
const char string_email[] = "email";
const char string_encoding[] = "encoding";
const char string_feature[] = "feature";
const char string_height[] = "height";
const char string_href[] = "href";
const char string_icon[] = "icon";
const char string_id[] = "id";
const char string_id_lower[] = "id-lower";
const char string_id_underscore[] = "id-underscore";
const char string_license[] = "license";
const char string_name[] = "name";
const char string_param[] = "param";
const char string_preference[] = "preference";
const char string_readonly[] = "readonly";
const char string_required[] = "required";
const char string_short[] = "short";
const char string_src[] = "src";
const char string_type[] = "type";
const char string_value[] = "value";
const char string_version[] = "version";
const char string_viewmodes[] = "viewmodes";
const char string_widget[] = "widget";
const char string_width[] = "width";
const char string_config_dot_xml[] = "config.xml";

/* other strings */
const char string_AGL_prefix[] = FWK_AGL_PREFIX;
const char string_AGL_permission_prefix[] = FWK_AGL_PREFIX "permission:";
const char string_AGL_widget_prefix[] = FWK_AGL_PREFIX "widget:";
const char string_defined_permission[] = "defined-permission";
const char string_dict[] = "dict";
const char string_file_properties[] = "file-properties";
const char string_idaver[] = "idaver";
const char string_index[] = "index";
const char string_level[] = "level";
const char string_list[] = "list";
const char string_main[] = "main";
const char string_optional[] = "optional";
const char string_provided_api[] = "provided-api";
const char string_provided_binding[] = "provided-binding";
const char string_provided_unit[] = "provided-unit";
const char string_required_api[] = "required-api";
const char string_required_binding[] = "required-binding";
const char string_required_permission[] = "required-permission";
const char string_targets[] = "targets";
const char string_sharp_target[] = "#target";


const char feature_required_api[] = FWK_AGL_PREFIX "widget:required-api";
const char feature_required_permission[] = FWK_AGL_PREFIX "widget:required-permission";
